// Compiled by ClojureScript 1.10.238 {:target :nodejs}
goog.provide('re_frame.fx');
goog.require('cljs.core');
goog.require('re_frame.router');
goog.require('re_frame.db');
goog.require('re_frame.interceptor');
goog.require('re_frame.interop');
goog.require('re_frame.events');
goog.require('re_frame.registrar');
goog.require('re_frame.loggers');
goog.require('re_frame.trace');
re_frame.fx.kind = new cljs.core.Keyword(null,"fx","fx",-1237829572);
if(cljs.core.truth_(re_frame.registrar.kinds.call(null,re_frame.fx.kind))){
} else {
throw (new Error("Assert failed: (re-frame.registrar/kinds kind)"));
}
/**
 * Register the given effect `handler` for the given `id`.
 * 
 *   `id` is keyword, often namespaced.
 *   `handler` is a side-effecting function which takes a single argument and whose return
 *   value is ignored.
 * 
 *   Example Use
 *   -----------
 * 
 *   First, registration ... associate `:effect2` with a handler.
 * 
 *   (reg-fx
 *   :effect2
 *   (fn [value]
 *      ... do something side-effect-y))
 * 
 *   Then, later, if an event handler were to return this effects map ...
 * 
 *   {...
 * :effect2  [1 2]}
 * 
 * ... then the `handler` `fn` we registered previously, using `reg-fx`, will be
 * called with an argument of `[1 2]`.
 */
re_frame.fx.reg_fx = (function re_frame$fx$reg_fx(id,handler){
return re_frame.registrar.register_handler.call(null,re_frame.fx.kind,id,handler);
});
/**
 * An interceptor whose `:after` actions the contents of `:effects`. As a result,
 *   this interceptor is Domino 3.
 * 
 *   This interceptor is silently added (by reg-event-db etc) to the front of
 *   interceptor chains for all events.
 * 
 *   For each key in `:effects` (a map), it calls the registered `effects handler`
 *   (see `reg-fx` for registration of effect handlers).
 * 
 *   So, if `:effects` was:
 *    {:dispatch  [:hello 42]
 *     :db        {...}
 *     :undo      "set flag"}
 * 
 *   it will call the registered effect handlers for each of the map's keys:
 *   `:dispatch`, `:undo` and `:db`. When calling each handler, provides the map
 *   value for that key - so in the example above the effect handler for :dispatch
 *   will be given one arg `[:hello 42]`.
 * 
 *   You cannot rely on the ordering in which effects are executed.
 */
re_frame.fx.do_fx = re_frame.interceptor.__GT_interceptor.call(null,new cljs.core.Keyword(null,"id","id",-1388402092),new cljs.core.Keyword(null,"do-fx","do-fx",1194163050),new cljs.core.Keyword(null,"after","after",594996914),(function re_frame$fx$do_fx_after(context){
if(re_frame.trace.is_trace_enabled_QMARK_.call(null)){
var _STAR_current_trace_STAR_8765 = re_frame.trace._STAR_current_trace_STAR_;
re_frame.trace._STAR_current_trace_STAR_ = re_frame.trace.start_trace.call(null,new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"op-type","op-type",-1636141668),new cljs.core.Keyword("event","do-fx","event/do-fx",1357330452)], null));

try{try{var seq__8766 = cljs.core.seq.call(null,new cljs.core.Keyword(null,"effects","effects",-282369292).cljs$core$IFn$_invoke$arity$1(context));
var chunk__8767 = null;
var count__8768 = (0);
var i__8769 = (0);
while(true){
if((i__8769 < count__8768)){
var vec__8770 = cljs.core._nth.call(null,chunk__8767,i__8769);
var effect_key = cljs.core.nth.call(null,vec__8770,(0),null);
var effect_value = cljs.core.nth.call(null,vec__8770,(1),null);
var temp__4655__auto___8786 = re_frame.registrar.get_handler.call(null,re_frame.fx.kind,effect_key,false);
if(cljs.core.truth_(temp__4655__auto___8786)){
var effect_fn_8787 = temp__4655__auto___8786;
effect_fn_8787.call(null,effect_value);
} else {
re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),"re-frame: no handler registered for effect:",effect_key,". Ignoring.");
}


var G__8788 = seq__8766;
var G__8789 = chunk__8767;
var G__8790 = count__8768;
var G__8791 = (i__8769 + (1));
seq__8766 = G__8788;
chunk__8767 = G__8789;
count__8768 = G__8790;
i__8769 = G__8791;
continue;
} else {
var temp__4657__auto__ = cljs.core.seq.call(null,seq__8766);
if(temp__4657__auto__){
var seq__8766__$1 = temp__4657__auto__;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__8766__$1)){
var c__4319__auto__ = cljs.core.chunk_first.call(null,seq__8766__$1);
var G__8792 = cljs.core.chunk_rest.call(null,seq__8766__$1);
var G__8793 = c__4319__auto__;
var G__8794 = cljs.core.count.call(null,c__4319__auto__);
var G__8795 = (0);
seq__8766 = G__8792;
chunk__8767 = G__8793;
count__8768 = G__8794;
i__8769 = G__8795;
continue;
} else {
var vec__8773 = cljs.core.first.call(null,seq__8766__$1);
var effect_key = cljs.core.nth.call(null,vec__8773,(0),null);
var effect_value = cljs.core.nth.call(null,vec__8773,(1),null);
var temp__4655__auto___8796 = re_frame.registrar.get_handler.call(null,re_frame.fx.kind,effect_key,false);
if(cljs.core.truth_(temp__4655__auto___8796)){
var effect_fn_8797 = temp__4655__auto___8796;
effect_fn_8797.call(null,effect_value);
} else {
re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),"re-frame: no handler registered for effect:",effect_key,". Ignoring.");
}


var G__8798 = cljs.core.next.call(null,seq__8766__$1);
var G__8799 = null;
var G__8800 = (0);
var G__8801 = (0);
seq__8766 = G__8798;
chunk__8767 = G__8799;
count__8768 = G__8800;
i__8769 = G__8801;
continue;
}
} else {
return null;
}
}
break;
}
}finally {if(re_frame.trace.is_trace_enabled_QMARK_.call(null)){
var end__2658__auto___8802 = re_frame.interop.now.call(null);
var duration__2659__auto___8803 = (end__2658__auto___8802 - new cljs.core.Keyword(null,"start","start",-355208981).cljs$core$IFn$_invoke$arity$1(re_frame.trace._STAR_current_trace_STAR_));
cljs.core.swap_BANG_.call(null,re_frame.trace.traces,cljs.core.conj,cljs.core.assoc.call(null,re_frame.trace._STAR_current_trace_STAR_,new cljs.core.Keyword(null,"duration","duration",1444101068),duration__2659__auto___8803,new cljs.core.Keyword(null,"end","end",-268185958),re_frame.interop.now.call(null)));

re_frame.trace.run_tracing_callbacks_BANG_.call(null,end__2658__auto___8802);
} else {
}
}}finally {re_frame.trace._STAR_current_trace_STAR_ = _STAR_current_trace_STAR_8765;
}} else {
var seq__8776 = cljs.core.seq.call(null,new cljs.core.Keyword(null,"effects","effects",-282369292).cljs$core$IFn$_invoke$arity$1(context));
var chunk__8777 = null;
var count__8778 = (0);
var i__8779 = (0);
while(true){
if((i__8779 < count__8778)){
var vec__8780 = cljs.core._nth.call(null,chunk__8777,i__8779);
var effect_key = cljs.core.nth.call(null,vec__8780,(0),null);
var effect_value = cljs.core.nth.call(null,vec__8780,(1),null);
var temp__4655__auto___8804 = re_frame.registrar.get_handler.call(null,re_frame.fx.kind,effect_key,false);
if(cljs.core.truth_(temp__4655__auto___8804)){
var effect_fn_8805 = temp__4655__auto___8804;
effect_fn_8805.call(null,effect_value);
} else {
re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),"re-frame: no handler registered for effect:",effect_key,". Ignoring.");
}


var G__8806 = seq__8776;
var G__8807 = chunk__8777;
var G__8808 = count__8778;
var G__8809 = (i__8779 + (1));
seq__8776 = G__8806;
chunk__8777 = G__8807;
count__8778 = G__8808;
i__8779 = G__8809;
continue;
} else {
var temp__4657__auto__ = cljs.core.seq.call(null,seq__8776);
if(temp__4657__auto__){
var seq__8776__$1 = temp__4657__auto__;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__8776__$1)){
var c__4319__auto__ = cljs.core.chunk_first.call(null,seq__8776__$1);
var G__8810 = cljs.core.chunk_rest.call(null,seq__8776__$1);
var G__8811 = c__4319__auto__;
var G__8812 = cljs.core.count.call(null,c__4319__auto__);
var G__8813 = (0);
seq__8776 = G__8810;
chunk__8777 = G__8811;
count__8778 = G__8812;
i__8779 = G__8813;
continue;
} else {
var vec__8783 = cljs.core.first.call(null,seq__8776__$1);
var effect_key = cljs.core.nth.call(null,vec__8783,(0),null);
var effect_value = cljs.core.nth.call(null,vec__8783,(1),null);
var temp__4655__auto___8814 = re_frame.registrar.get_handler.call(null,re_frame.fx.kind,effect_key,false);
if(cljs.core.truth_(temp__4655__auto___8814)){
var effect_fn_8815 = temp__4655__auto___8814;
effect_fn_8815.call(null,effect_value);
} else {
re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),"re-frame: no handler registered for effect:",effect_key,". Ignoring.");
}


var G__8816 = cljs.core.next.call(null,seq__8776__$1);
var G__8817 = null;
var G__8818 = (0);
var G__8819 = (0);
seq__8776 = G__8816;
chunk__8777 = G__8817;
count__8778 = G__8818;
i__8779 = G__8819;
continue;
}
} else {
return null;
}
}
break;
}
}
}));
re_frame.fx.reg_fx.call(null,new cljs.core.Keyword(null,"dispatch-later","dispatch-later",291951390),(function (value){
var seq__8820 = cljs.core.seq.call(null,value);
var chunk__8821 = null;
var count__8822 = (0);
var i__8823 = (0);
while(true){
if((i__8823 < count__8822)){
var map__8824 = cljs.core._nth.call(null,chunk__8821,i__8823);
var map__8824__$1 = ((((!((map__8824 == null)))?(((((map__8824.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__8824.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__8824):map__8824);
var effect = map__8824__$1;
var ms = cljs.core.get.call(null,map__8824__$1,new cljs.core.Keyword(null,"ms","ms",-1152709733));
var dispatch = cljs.core.get.call(null,map__8824__$1,new cljs.core.Keyword(null,"dispatch","dispatch",1319337009));
if(((cljs.core.empty_QMARK_.call(null,dispatch)) || (!(typeof ms === 'number')))){
re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),"re-frame: ignoring bad :dispatch-later value:",effect);
} else {
re_frame.interop.set_timeout_BANG_.call(null,((function (seq__8820,chunk__8821,count__8822,i__8823,map__8824,map__8824__$1,effect,ms,dispatch){
return (function (){
return re_frame.router.dispatch.call(null,dispatch);
});})(seq__8820,chunk__8821,count__8822,i__8823,map__8824,map__8824__$1,effect,ms,dispatch))
,ms);
}


var G__8828 = seq__8820;
var G__8829 = chunk__8821;
var G__8830 = count__8822;
var G__8831 = (i__8823 + (1));
seq__8820 = G__8828;
chunk__8821 = G__8829;
count__8822 = G__8830;
i__8823 = G__8831;
continue;
} else {
var temp__4657__auto__ = cljs.core.seq.call(null,seq__8820);
if(temp__4657__auto__){
var seq__8820__$1 = temp__4657__auto__;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__8820__$1)){
var c__4319__auto__ = cljs.core.chunk_first.call(null,seq__8820__$1);
var G__8832 = cljs.core.chunk_rest.call(null,seq__8820__$1);
var G__8833 = c__4319__auto__;
var G__8834 = cljs.core.count.call(null,c__4319__auto__);
var G__8835 = (0);
seq__8820 = G__8832;
chunk__8821 = G__8833;
count__8822 = G__8834;
i__8823 = G__8835;
continue;
} else {
var map__8826 = cljs.core.first.call(null,seq__8820__$1);
var map__8826__$1 = ((((!((map__8826 == null)))?(((((map__8826.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__8826.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__8826):map__8826);
var effect = map__8826__$1;
var ms = cljs.core.get.call(null,map__8826__$1,new cljs.core.Keyword(null,"ms","ms",-1152709733));
var dispatch = cljs.core.get.call(null,map__8826__$1,new cljs.core.Keyword(null,"dispatch","dispatch",1319337009));
if(((cljs.core.empty_QMARK_.call(null,dispatch)) || (!(typeof ms === 'number')))){
re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),"re-frame: ignoring bad :dispatch-later value:",effect);
} else {
re_frame.interop.set_timeout_BANG_.call(null,((function (seq__8820,chunk__8821,count__8822,i__8823,map__8826,map__8826__$1,effect,ms,dispatch,seq__8820__$1,temp__4657__auto__){
return (function (){
return re_frame.router.dispatch.call(null,dispatch);
});})(seq__8820,chunk__8821,count__8822,i__8823,map__8826,map__8826__$1,effect,ms,dispatch,seq__8820__$1,temp__4657__auto__))
,ms);
}


var G__8836 = cljs.core.next.call(null,seq__8820__$1);
var G__8837 = null;
var G__8838 = (0);
var G__8839 = (0);
seq__8820 = G__8836;
chunk__8821 = G__8837;
count__8822 = G__8838;
i__8823 = G__8839;
continue;
}
} else {
return null;
}
}
break;
}
}));
re_frame.fx.reg_fx.call(null,new cljs.core.Keyword(null,"dispatch","dispatch",1319337009),(function (value){
if(!(cljs.core.vector_QMARK_.call(null,value))){
return re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),"re-frame: ignoring bad :dispatch value. Expected a vector, but got:",value);
} else {
return re_frame.router.dispatch.call(null,value);
}
}));
re_frame.fx.reg_fx.call(null,new cljs.core.Keyword(null,"dispatch-n","dispatch-n",-504469236),(function (value){
if(!(cljs.core.sequential_QMARK_.call(null,value))){
return re_frame.loggers.console.call(null,new cljs.core.Keyword(null,"error","error",-978969032),"re-frame: ignoring bad :dispatch-n value. Expected a collection, got got:",value);
} else {
var seq__8840 = cljs.core.seq.call(null,cljs.core.remove.call(null,cljs.core.nil_QMARK_,value));
var chunk__8841 = null;
var count__8842 = (0);
var i__8843 = (0);
while(true){
if((i__8843 < count__8842)){
var event = cljs.core._nth.call(null,chunk__8841,i__8843);
re_frame.router.dispatch.call(null,event);


var G__8844 = seq__8840;
var G__8845 = chunk__8841;
var G__8846 = count__8842;
var G__8847 = (i__8843 + (1));
seq__8840 = G__8844;
chunk__8841 = G__8845;
count__8842 = G__8846;
i__8843 = G__8847;
continue;
} else {
var temp__4657__auto__ = cljs.core.seq.call(null,seq__8840);
if(temp__4657__auto__){
var seq__8840__$1 = temp__4657__auto__;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__8840__$1)){
var c__4319__auto__ = cljs.core.chunk_first.call(null,seq__8840__$1);
var G__8848 = cljs.core.chunk_rest.call(null,seq__8840__$1);
var G__8849 = c__4319__auto__;
var G__8850 = cljs.core.count.call(null,c__4319__auto__);
var G__8851 = (0);
seq__8840 = G__8848;
chunk__8841 = G__8849;
count__8842 = G__8850;
i__8843 = G__8851;
continue;
} else {
var event = cljs.core.first.call(null,seq__8840__$1);
re_frame.router.dispatch.call(null,event);


var G__8852 = cljs.core.next.call(null,seq__8840__$1);
var G__8853 = null;
var G__8854 = (0);
var G__8855 = (0);
seq__8840 = G__8852;
chunk__8841 = G__8853;
count__8842 = G__8854;
i__8843 = G__8855;
continue;
}
} else {
return null;
}
}
break;
}
}
}));
re_frame.fx.reg_fx.call(null,new cljs.core.Keyword(null,"deregister-event-handler","deregister-event-handler",-1096518994),(function (value){
var clear_event = cljs.core.partial.call(null,re_frame.registrar.clear_handlers,re_frame.events.kind);
if(cljs.core.sequential_QMARK_.call(null,value)){
var seq__8856 = cljs.core.seq.call(null,value);
var chunk__8857 = null;
var count__8858 = (0);
var i__8859 = (0);
while(true){
if((i__8859 < count__8858)){
var event = cljs.core._nth.call(null,chunk__8857,i__8859);
clear_event.call(null,event);


var G__8860 = seq__8856;
var G__8861 = chunk__8857;
var G__8862 = count__8858;
var G__8863 = (i__8859 + (1));
seq__8856 = G__8860;
chunk__8857 = G__8861;
count__8858 = G__8862;
i__8859 = G__8863;
continue;
} else {
var temp__4657__auto__ = cljs.core.seq.call(null,seq__8856);
if(temp__4657__auto__){
var seq__8856__$1 = temp__4657__auto__;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__8856__$1)){
var c__4319__auto__ = cljs.core.chunk_first.call(null,seq__8856__$1);
var G__8864 = cljs.core.chunk_rest.call(null,seq__8856__$1);
var G__8865 = c__4319__auto__;
var G__8866 = cljs.core.count.call(null,c__4319__auto__);
var G__8867 = (0);
seq__8856 = G__8864;
chunk__8857 = G__8865;
count__8858 = G__8866;
i__8859 = G__8867;
continue;
} else {
var event = cljs.core.first.call(null,seq__8856__$1);
clear_event.call(null,event);


var G__8868 = cljs.core.next.call(null,seq__8856__$1);
var G__8869 = null;
var G__8870 = (0);
var G__8871 = (0);
seq__8856 = G__8868;
chunk__8857 = G__8869;
count__8858 = G__8870;
i__8859 = G__8871;
continue;
}
} else {
return null;
}
}
break;
}
} else {
return clear_event.call(null,value);
}
}));
re_frame.fx.reg_fx.call(null,new cljs.core.Keyword(null,"db","db",993250759),(function (value){
if(!((cljs.core.deref.call(null,re_frame.db.app_db) === value))){
return cljs.core.reset_BANG_.call(null,re_frame.db.app_db,value);
} else {
return null;
}
}));

//# sourceMappingURL=fx.js.map
